==> xlniuxdata-vipgame-1.0.20-sources.jar: com/xunlei/niux/data/vipgame/vo/CustomerDetailQuery.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;

/**
 * 所有客户详情查询
 * @author lisu
 *  2013-02-20
 */
@Table(tableName = "customerdetailquery", pkFieldName = "seqId", pkFieldAssign = false)
public class CustomerDetailQuery {


	private Long seqId;
	private String uid;
	private String account;
	private Integer vipGrade;
	private Integer bvipGrade;
	private Integer liveVipGrade;
	private Integer vipStatus;
	private Integer gameCount;
	private Integer payCount;
	private Long payTotalAmt;
	private Long livePayTotalAmt;
	private String lastPayTime;
	@Column(columnName="lastPayTime",isWhereColumn=true,operator=Operator.GE)
	private String fromLastPayTime;
	@Column(columnName="lastPayTime",isWhereColumn=true,operator=Operator.LT)
	private String toLastPayTime;
	private String lastLoginTime;
	private Integer callCount;
	private Integer integral;
	private String phone;
	private String contactNumber;
	private String qq;
	private String email;
	private String birthday;
	private Boolean isNew;
	private Boolean isPromote;
	private Boolean isBack;
	private Long lastModifyAmt;
	private String loginGameId;
	private String payGameId;
	private String upGameId;
	private Long orderTotalAmt;
	private String optime;
	private String lastCaller;
	private String lastCallTime;
	private String lastUpdateTime;
	@Column(columnName="lastUpdateTime",isWhereColumn=true,operator=Operator.GE)
	private String fromUpdateTime;
	@Column(columnName="lastUpdateTime",isWhereColumn=true,operator=Operator.LT)
	private String toUpdateTime;
	private Integer rebateCount;
	private Long rebateMoney;
	private String customerService;
	private String loginGameIds;
	private String payGameIds;
	
	
	public String getFromLastPayTime() {
		return fromLastPayTime;
	}
	public void setFromLastPayTime(String fromLastPayTime) {
		this.fromLastPayTime = fromLastPayTime;
	}
	public String getToLastPayTime() {
		return toLastPayTime;
	}
	public void setToLastPayTime(String toLastPayTime) {
		this.toLastPayTime = toLastPayTime;
	}
	public String getPayGameIds() {
		return payGameIds;
	}
	public void setPayGameIds(String payGameIds) {
		this.payGameIds = payGameIds;
	}
	public String getLoginGameIds() {
		return loginGameIds;
	}
	public void setLoginGameIds(String loginGameIds) {
		this.loginGameIds = loginGameIds;
	}
	public String getCustomerService() {
		return customerService;
	}
	public void setCustomerService(String customerService) {
		this.customerService = customerService;
	}
	public Integer getRebateCount() {
		return rebateCount;
	}
	public void setRebateCount(Integer rebateCount) {
		this.rebateCount = rebateCount;
	}
	public Long getRebateMoney() {
		return rebateMoney;
	}
	public void setRebateMoney(Long rebateMoney) {
		this.rebateMoney = rebateMoney;
	}
	public String getFromUpdateTime() {
		return fromUpdateTime;
	}
	public void setFromUpdateTime(String fromUpdateTime) {
		this.fromUpdateTime = fromUpdateTime;
	}
	public String getToUpdateTime() {
		return toUpdateTime;
	}
	public void setToUpdateTime(String toUpdateTime) {
		this.toUpdateTime = toUpdateTime;
	}
	public String getLastUpdateTime() {
		return lastUpdateTime;
	}
	public void setLastUpdateTime(String lastUpdateTime) {
		this.lastUpdateTime = lastUpdateTime;
	}
	public String getLastCaller() {
		return lastCaller;
	}
	public void setLastCaller(String lastCaller) {
		this.lastCaller = lastCaller;
	}
	public String getLastCallTime() {
		return lastCallTime;
	}
	public void setLastCallTime(String lastCallTime) {
		this.lastCallTime = lastCallTime;
	}
	public String getOptime() {
		return optime;
	}
	public void setOptime(String optime) {
		this.optime = optime;
	}
	public String getUpGameId() {
		return upGameId;
	}
	public void setUpGameId(String upGameId) {
		this.upGameId = upGameId;
	}
	public Long getOrderTotalAmt() {
		return orderTotalAmt;
	}
	public void setOrderTotalAmt(Long orderTotalAmt) {
		this.orderTotalAmt = orderTotalAmt;
	}
	public String getLoginGameId() {
		return loginGameId;
	}
	public void setLoginGameId(String loginGameId) {
		this.loginGameId = loginGameId;
	}
	public String getPayGameId() {
		return payGameId;
	}
	public void setPayGameId(String payGameId) {
		this.payGameId = payGameId;
	}	
	public Long getSeqId() {
		return seqId;
	}
	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}
	public String getUid() {
		return uid;
	}
	public void setUid(String uid) {
		this.uid = uid;
	}
	public String getAccount() {
		return account;
	}
	public void setAccount(String account) {
		this.account = account;
	}
	public Integer getVipGrade() {
		return vipGrade;
	}
	public void setVipGrade(Integer vipGrade) {
		this.vipGrade = vipGrade;
	}
	public Integer getVipStatus() {
		return vipStatus;
	}
	public void setVipStatus(Integer vipStatus) {
		this.vipStatus = vipStatus;
	}
	public Integer getGameCount() {
		return gameCount;
	}
	public void setGameCount(Integer gameCount) {
		this.gameCount = gameCount;
	}
	public Integer getPayCount() {
		return payCount;
	}
	public void setPayCount(Integer payCount) {
		this.payCount = payCount;
	}
	public Long getPayTotalAmt() {
		return payTotalAmt;
	}
	public void setPayTotalAmt(Long payTotalAmt) {
		this.payTotalAmt = payTotalAmt;
	}
	public String getLastPayTime() {
		return lastPayTime;
	}
	public void setLastPayTime(String lastPayTime) {
		this.lastPayTime = lastPayTime;
	}
	public String getLastLoginTime() {
		return lastLoginTime;
	}
	public void setLastLoginTime(String lastLoginTime) {
		this.lastLoginTime = lastLoginTime;
	}
	public Integer getCallCount() {
		return callCount;
	}
	public void setCallCount(Integer callCount) {
		this.callCount = callCount;
	}
	public Integer getIntegral() {
		return integral;
	}
	public void setIntegral(Integer integral) {
		this.integral = integral;
	}
	public String getPhone() {
		return phone;
	}
	public void setPhone(String phone) {
		this.phone = phone;
	}
	public String getContactNumber() {
		return contactNumber;
	}
	public void setContactNumber(String contactNumber) {
		this.contactNumber = contactNumber;
	}
	public String getQq() {
		return qq;
	}
	public void setQq(String qq) {
		this.qq = qq;
	}
	public String getEmail() {
		return email;
	}
	public void setEmail(String email) {
		this.email = email;
	}
	public String getBirthday() {
		return birthday;
	}
	public void setBirthday(String birthday) {
		this.birthday = birthday;
	}
	public Long getLastModifyAmt() {
		return lastModifyAmt;
	}
	public void setLastModifyAmt(Long lastModifyAmt) {
		this.lastModifyAmt = lastModifyAmt;
	}
	public Boolean getIsNew() {
		return isNew;
	}
	public void setIsNew(Boolean isNew) {
		this.isNew = isNew;
	}
	public Boolean getIsPromote() {
		return isPromote;
	}
	public void setIsPromote(Boolean isPromote) {
		this.isPromote = isPromote;
	}
	public Boolean getIsBack() {
		return isBack;
	}
	public void setIsBack(Boolean isBack) {
		this.isBack = isBack;
	}
	public Integer getLiveVipGrade() {
		return liveVipGrade;
	}
	public void setLiveVipGrade(Integer liveVipGrade) {
		this.liveVipGrade = liveVipGrade;
	}
	public Long getLivePayTotalAmt() {
		return livePayTotalAmt;
	}
	public void setLivePayTotalAmt(Long livePayTotalAmt) {
		this.livePayTotalAmt = livePayTotalAmt;
	}
	public Integer getBvipGrade() {
		return bvipGrade;
	}
	public void setBvipGrade(Integer bvipGrade) {
		this.bvipGrade = bvipGrade;
	}
	
}

==> xlniuxdata-vipgame-1.0.54-sources.jar: com/xunlei/niux/data/vipgame/vo/CustomerDetailQuery.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;

/**
 * 所有客户详情查询
 * @author lisu
 *  2013-02-20
 */
@Table(tableName = "customerdetailquery", pkFieldName = "seqId", pkFieldAssign = false)
public class CustomerDetailQuery {


	private Long seqId;
	private String uid;
	private String account;
	private Integer vipGrade;
	private Integer bvipGrade;
	private Integer liveVipGrade;
	private Integer vipStatus;
	private Integer gameCount;
	private Integer payCount;
	private Long payTotalAmt;
	private Long livePayTotalAmt;
	private String lastPayTime;
	@Column(columnName="lastPayTime",isWhereColumn=true,operator=Operator.GE)
	private String fromLastPayTime;
	@Column(columnName="lastPayTime",isWhereColumn=true,operator=Operator.LT)
	private String toLastPayTime;
	private String lastLoginTime;
    @Column(columnName="lastLoginTime",isWhereColumn=true,operator=Operator.GE)
    private String fromLastLoginTime;
    @Column(columnName="lastLoginTime",isWhereColumn=true,operator=Operator.LT)
    private String toLastLoginTime;
	private Integer callCount;
	private Integer integral;
	private String phone;
	private String contactNumber;
	private String qq;
	private String email;
	private String birthday;
	private Boolean isNew;
	private Boolean isPromote;
	private Boolean isBack;
	private Long lastModifyAmt;
	private String loginGameId;
	private String payGameId;
	private String upGameId;
	private Long orderTotalAmt;
	private String optime;
	private String lastCaller;
	private String lastCallTime;
	private String lastUpdateTime;
	@Column(columnName="lastUpdateTime",isWhereColumn=true,operator=Operator.GE)
	private String fromUpdateTime;
	@Column(columnName="lastUpdateTime",isWhereColumn=true,operator=Operator.LT)
	private String toUpdateTime;
	private Integer rebateCount;
	private Long rebateMoney;
	private String customerService;
	private String loginGameIds;
	private String payGameIds;

    public String getFromLastLoginTime() {
        return fromLastLoginTime;
    }

    public void setFromLastLoginTime(String fromLastLoginTime) {
        this.fromLastLoginTime = fromLastLoginTime;
    }

    public String getToLastLoginTime() {
        return toLastLoginTime;
    }

    public void setToLastLoginTime(String toLastLoginTime) {
        this.toLastLoginTime = toLastLoginTime;
    }

    public String getFromLastPayTime() {
		return fromLastPayTime;
	}
	public void setFromLastPayTime(String fromLastPayTime) {
		this.fromLastPayTime = fromLastPayTime;
	}
	public String getToLastPayTime() {
		return toLastPayTime;
	}
	public void setToLastPayTime(String toLastPayTime) {
		this.toLastPayTime = toLastPayTime;
	}
	public String getPayGameIds() {
		return payGameIds;
	}
	public void setPayGameIds(String payGameIds) {
		this.payGameIds = payGameIds;
	}
	public String getLoginGameIds() {
		return loginGameIds;
	}
	public void setLoginGameIds(String loginGameIds) {
		this.loginGameIds = loginGameIds;
	}
	public String getCustomerService() {
		return customerService;
	}
	public void setCustomerService(String customerService) {
		this.customerService = customerService;
	}
	public Integer getRebateCount() {
		return rebateCount;
	}
	public void setRebateCount(Integer rebateCount) {
		this.rebateCount = rebateCount;
	}
	public Long getRebateMoney() {
		return rebateMoney;
	}
	public void setRebateMoney(Long rebateMoney) {
		this.rebateMoney = rebateMoney;
	}
	public String getFromUpdateTime() {
		return fromUpdateTime;
	}
	public void setFromUpdateTime(String fromUpdateTime) {
		this.fromUpdateTime = fromUpdateTime;
	}
	public String getToUpdateTime() {
		return toUpdateTime;
	}
	public void setToUpdateTime(String toUpdateTime) {
		this.toUpdateTime = toUpdateTime;
	}
	public String getLastUpdateTime() {
		return lastUpdateTime;
	}
	public void setLastUpdateTime(String lastUpdateTime) {
		this.lastUpdateTime = lastUpdateTime;
	}
	public String getLastCaller() {
		return lastCaller;
	}
	public void setLastCaller(String lastCaller) {
		this.lastCaller = lastCaller;
	}
	public String getLastCallTime() {
		return lastCallTime;
	}
	public void setLastCallTime(String lastCallTime) {
		this.lastCallTime = lastCallTime;
	}
	public String getOptime() {
		return optime;
	}
	public void setOptime(String optime) {
		this.optime = optime;
	}
	public String getUpGameId() {
		return upGameId;
	}
	public void setUpGameId(String upGameId) {
		this.upGameId = upGameId;
	}
	public Long getOrderTotalAmt() {
		return orderTotalAmt;
	}
	public void setOrderTotalAmt(Long orderTotalAmt) {
		this.orderTotalAmt = orderTotalAmt;
	}
	public String getLoginGameId() {
		return loginGameId;
	}
	public void setLoginGameId(String loginGameId) {
		this.loginGameId = loginGameId;
	}
	public String getPayGameId() {
		return payGameId;
	}
	public void setPayGameId(String payGameId) {
		this.payGameId = payGameId;
	}	
	public Long getSeqId() {
		return seqId;
	}
	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}
	public String getUid() {
		return uid;
	}
	public void setUid(String uid) {
		this.uid = uid;
	}
	public String getAccount() {
		return account;
	}
	public void setAccount(String account) {
		this.account = account;
	}
	public Integer getVipGrade() {
		return vipGrade;
	}
	public void setVipGrade(Integer vipGrade) {
		this.vipGrade = vipGrade;
	}
	public Integer getVipStatus() {
		return vipStatus;
	}
	public void setVipStatus(Integer vipStatus) {
		this.vipStatus = vipStatus;
	}
	public Integer getGameCount() {
		return gameCount;
	}
	public void setGameCount(Integer gameCount) {
		this.gameCount = gameCount;
	}
	public Integer getPayCount() {
		return payCount;
	}
	public void setPayCount(Integer payCount) {
		this.payCount = payCount;
	}
	public Long getPayTotalAmt() {
		return payTotalAmt;
	}
	public void setPayTotalAmt(Long payTotalAmt) {
		this.payTotalAmt = payTotalAmt;
	}
	public String getLastPayTime() {
		return lastPayTime;
	}
	public void setLastPayTime(String lastPayTime) {
		this.lastPayTime = lastPayTime;
	}
	public String getLastLoginTime() {
		return lastLoginTime;
	}
	public void setLastLoginTime(String lastLoginTime) {
		this.lastLoginTime = lastLoginTime;
	}
	public Integer getCallCount() {
		return callCount;
	}
	public void setCallCount(Integer callCount) {
		this.callCount = callCount;
	}
	public Integer getIntegral() {
		return integral;
	}
	public void setIntegral(Integer integral) {
		this.integral = integral;
	}
	public String getPhone() {
		return phone;
	}
	public void setPhone(String phone) {
		this.phone = phone;
	}
	public String getContactNumber() {
		return contactNumber;
	}
	public void setContactNumber(String contactNumber) {
		this.contactNumber = contactNumber;
	}
	public String getQq() {
		return qq;
	}
	public void setQq(String qq) {
		this.qq = qq;
	}
	public String getEmail() {
		return email;
	}
	public void setEmail(String email) {
		this.email = email;
	}
	public String getBirthday() {
		return birthday;
	}
	public void setBirthday(String birthday) {
		this.birthday = birthday;
	}
	public Long getLastModifyAmt() {
		return lastModifyAmt;
	}
	public void setLastModifyAmt(Long lastModifyAmt) {
		this.lastModifyAmt = lastModifyAmt;
	}
	public Boolean getIsNew() {
		return isNew;
	}
	public void setIsNew(Boolean isNew) {
		this.isNew = isNew;
	}
	public Boolean getIsPromote() {
		return isPromote;
	}
	public void setIsPromote(Boolean isPromote) {
		this.isPromote = isPromote;
	}
	public Boolean getIsBack() {
		return isBack;
	}
	public void setIsBack(Boolean isBack) {
		this.isBack = isBack;
	}
	public Integer getLiveVipGrade() {
		return liveVipGrade;
	}
	public void setLiveVipGrade(Integer liveVipGrade) {
		this.liveVipGrade = liveVipGrade;
	}
	public Long getLivePayTotalAmt() {
		return livePayTotalAmt;
	}
	public void setLivePayTotalAmt(Long livePayTotalAmt) {
		this.livePayTotalAmt = livePayTotalAmt;
	}
	public Integer getBvipGrade() {
		return bvipGrade;
	}
	public void setBvipGrade(Integer bvipGrade) {
		this.bvipGrade = bvipGrade;
	}
	
}
